# SLBaumgartner
# plugin to force SketchUp to save a preview jpeg image whenever
# a skp file is saved.  This image is compatible with my
# QuickLook thumbnail viewer.  

require "sketchup.rb"

class PreviewMaker < Sketchup::ModelObserver
  def onSaveModel(theModel)
    thumbsDir = File.expand_path("~/.QL_SketchUp/")
    if(!FileTest.exists?(thumbsDir))
        Dir.mkdir(thumbsDir)
    end
      #puts "thumbsDir is " + thumbsDir.to_s
    basePath = theModel.path[0..-5]
    namebase = basePath.rindex("/")
    imgname = basePath[namebase..-1]+".pv.jpg"
    previewFile = thumbsDir + imgname
      #puts "preview file is " + previewFile
      
    # width, height, and compression were chosen to provide a
    # reasonably clean representation at all thumbnail scales
    # without requiring an excessively large image file.
    previewKeys = {
      :filename => previewFile,
      :width => 800,
      :height => 600,
      :compression => 0.3
    }
    theView = theModel.active_view
    result = theView.write_image(previewKeys)
      #puts "write_image returned " + result.to_s
  end
end

class NewModel < Sketchup::AppObserver
  def onNewModel(model)
    model.add_observer(PreviewMaker.new())
  end

  def onOpenModel(model)
    model.add_observer(PreviewMaker.new())
  end
end

Sketchup.add_observer(NewModel.new())
